==> cyphesis-cpp_0.5.20.orig.tar.gz: cyphesis-0.5.20/rulesets/CalendarProperty.cpp <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2005 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

// $Id$

#include "CalendarProperty.h"

#include "modules/DateTime.h"

#include "common/debug.h"

#include <cassert>

static const bool debug_flag = false;

using Atlas::Message::Element;
using Atlas::Message::MapType;
using Atlas::Message::ListType;
using Atlas::Message::FloatType;

CalendarProperty::CalendarProperty(unsigned int flags) : PropertyBase(flags)
{
}

bool CalendarProperty::get(Element & ent) const
{
    MapType & c = (ent = MapType()).asMap();
    c["seconds_per_minute"] = (int)DateTime::spm();
    c["minutes_per_hour"] = (int)DateTime::mph();
    c["hours_per_day"] = (int)DateTime::hpd();
    c["days_per_month"] = (int)DateTime::dpm();
    c["months_per_year"] = (int)DateTime::mpy();
    return true;
}

void CalendarProperty::set(const Element & ent)
{
    return;
}

==> cyphesis-cpp_0.5.21.orig.tar.gz: cyphesis-0.5.21/rulesets/CalendarProperty.cpp <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2005 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

// $Id: 6f4af6306e28518fce35cbdf5b809916d4d767a6 $

#include "CalendarProperty.h"

#include "modules/DateTime.h"

#include "common/debug.h"

#include <cassert>

static const bool debug_flag = false;

using Atlas::Message::Element;
using Atlas::Message::MapType;
using Atlas::Message::ListType;
using Atlas::Message::FloatType;

CalendarProperty::CalendarProperty()
{
}

bool CalendarProperty::get(Element & ent) const
{
    MapType & c = (ent = MapType()).asMap();
    c["seconds_per_minute"] = (int)DateTime::spm();
    c["minutes_per_hour"] = (int)DateTime::mph();
    c["hours_per_day"] = (int)DateTime::hpd();
    c["days_per_month"] = (int)DateTime::dpm();
    c["months_per_year"] = (int)DateTime::mpy();
    return true;
}

void CalendarProperty::set(const Element & ent)
{
    return;
}
